from __future__ import absolute_import, unicode_literals

import unittest

from wagtail.wagtailcore.hooks import get_hooks

from wagtailgmaps.wagtail_hooks import editor_css, editor_js


class TestWagtailHooks(unittest.TestCase):
    def test_editor_css(self):
        self.assertEqual(
            editor_css(),
            '<link rel="stylesheet" href="/static/wagtailgmaps/css/admin.css">'
        )

    def test_insert_editor_css_hook(self):
        hooks = get_hooks('insert_editor_css')
        self.assertIn(editor_css, hooks, 'Editor CSS should be inserted automatically.')

    # def test_editor_js(self):
    #     self.assertEqual(
    #         editor_js(), '<script src=""></script>')

    def test_insert_editor_js(self):
        hooks = get_hooks('insert_editor_js')
        self.assertIn(editor_js, hooks, 'Editor JS should be inserted automatically.')



from __future__ import absolute_import, unicode_literals

from django.conf import settings
from django.contrib.staticfiles.templatetags.staticfiles import static
from django.utils.html import format_html_join
from wagtail.wagtailcore import hooks


@hooks.register('insert_editor_js')
def editor_js():
    js_files = (
        'https://maps.googleapis.com/maps/api/js?key={}'.format(settings.WAGTAIL_ADDRESS_MAP_KEY),
        static('wagtailgmaps/js/map-field-panel.js'),
    )
    js_includes = format_html_join(
        '\n',
        '<script type="text/javascript" src="{}"></script>',
        ((filename,) for filename in js_files)
    )
    return js_includes


@hooks.register('insert_editor_css')
def editor_css():
    css_files = (
        'wagtailgmaps/css/admin.css',
    )
    css_includes = format_html_join(
        '\n',
        '<link rel="stylesheet" href="{0}">',
        ((static(filename),) for filename in css_files)
    )
    return css_includes



from __future__ import absolute_import, unicode_literals

import random
import string

from django.conf import settings
from django.template.loader import render_to_string
from django.utils.safestring import mark_safe
from wagtail.wagtailadmin.edit_handlers import (
    BaseCompositeEditHandler, FieldPanel, widget_with_script)


def random_string(length=6, chars=string.ascii_lowercase):
    return ''.join(random.SystemRandom().choice(chars) for _ in range(length))


class BaseMapFieldPanel(BaseCompositeEditHandler):
    template = 'wagtailgmaps/edit_handlers/map_field_panel.html'
    js_template = 'wagtailgmaps/edit_handlers/map_field_panel.js'

    def classes(self):
        classes = super(BaseMapFieldPanel, self).classes()
        classes.append('multi-field')

        return classes

    def render(self):

        if (self.centre is None) or (self.centre == ''):
            try:
                self.centre = settings.WAGTAIL_ADDRESS_MAP_CENTER
            except AttributeError:
                pass

        try:
            selected_location = self.children[0].form[self.fieldname].value()
            if selected_location:
                self.centre = selected_location
        except KeyError:
            pass

        map_id = random_string()

        if self.zoom is None:
            try:
                self.zoom = settings.WAGTAIL_ADDRESS_MAP_ZOOM
            except AttributeError:
                self.zoom = 8

        try:
            apikey = settings.WAGTAIL_ADDRESS_MAP_KEY
        except AttributeError:
            raise Exception('Google Maps API key is missing from settings')

        width = 100
        width_units = '%'
        height = 300
        height_units = 'px'

        ctx = {
            'self': self,
            'map_id': map_id,
            'address': self.centre,
            'zoom': self.zoom,
            'width': width,
            'width_units': width_units,
            'height': height,
            'height_units': height_units,
            'gmaps_api_key': apikey,
            'latlng': self.latlng,
        }

        js = mark_safe(render_to_string(self.js_template, ctx))
        fieldset = render_to_string(self.template, ctx)
        return widget_with_script(fieldset, js)


class MapFieldPanel(object):
    def __init__(self, fieldname, heading='Location', classname='', latlng=False, centre='', zoom=8):
        self.children = [
            FieldPanel(fieldname),
        ]
        self.fieldname = fieldname
        self.heading = heading
        self.classname = classname
        self.centre = centre
        self.zoom = zoom
        self.latlng = latlng

    def bind_to_model(self, model):
        return type(str('_MapFieldPanel'), (BaseMapFieldPanel,), {
            'model': model,
            'children': [child.bind_to_model(model) for child in self.children],
            'fieldname': self.fieldname,
            'heading': self.heading,
            'classname': self.classname,
            'centre': self.centre,
            'zoom': self.zoom,
            'latlng': self.latlng,
        })



from __future__ import absolute_import, unicode_literals

import os

from setuptools import find_packages, setup

from wagtailgmaps import __version__

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

# Package dependencies
install_requires = [
]

# Testing dependencies
testing_extras = [
    # Required for running the tests
    'tox>=2.3.1,<2.4',

    # For coverage and PEP8 linting
    'coverage>=4.1.0,<4.2',
    'flake8>=3.2.0,<3.3',
    'flake8-colors>=0.1.6,<1',
    'isort==4.2.5',

    # For test site
    'wagtail==1.12',
]

# Documentation dependencies
documentation_extras = [

]

setup(
    name='wagtailgmaps',
    version=__version__,
    packages=find_packages(),
    include_package_data=True,
    license='MIT',
    description='Google Maps widget for address fields in Wagtail',
    long_description=README,
    url='https://github.com/springload/wagtailgmaps/',
    author='Springload',
    author_email='hello@springload.co.nz',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    install_requires=install_requires,
    extras_require={
        'testing': testing_extras,
        'docs': documentation_extras,
    },
)
